@@ -8,11 +8,14 @@
 #ifndef VMWARE_H
 #define VMWARE_H
 
+#include <string.h>
+
 #include "xf86.h"
 #include "xf86_OSproc.h"
-#include "xf86_ansic.h"
 #include "xf86Resources.h"
 
+#include <X11/extensions/panoramiXproto.h>
+
 #include "compiler.h"	        /* inb/outb */
 
 #include "xf86PciInfo.h"	/* pci vendor id */
@@ -51,6 +54,8 @@ typedef struct {
     CARD32 svga_reg_id;
 } VMWARERegRec, *VMWARERegPtr;
 
+typedef xXineramaScreenInfo VMWAREXineramaRec, *VMWAREXineramaPtr;
+
 typedef struct {
     EntityInfoPtr pEnt;
     pciVideoPtr PciInfo;
@@ -76,6 +81,10 @@ typedef struct {
     VMWARERegRec SavedReg;
     VMWARERegRec ModeReg;
 
+    DisplayModePtr initialMode;
+    DisplayModePtr dynMode1;
+    DisplayModePtr dynMode2;
+
     Bool* pvtSema;
 
     Bool noAccel;
@@ -98,7 +107,7 @@ typedef struct {
 
     unsigned char* mmioVirtBase;
     CARD32* vmwareFIFO;
-    Bool canPitchLock;
+    Bool hasPitchLockFIFOReg;
 
     xf86CursorInfoPtr CursorInfoRec;
     struct {
@@ -133,6 +142,18 @@ typedef struct {
     SVGASurface* curPict;
     int op;
 
+    /*
+     * Xinerama state
+     */
+    Bool xinerama;
+    Bool xineramaStatic;
+
+    VMWAREXineramaPtr xineramaState;
+    unsigned int xineramaNumOutputs;
+
+    VMWAREXineramaPtr xineramaNextState;
+    unsigned int xineramaNextNumOutputs;
+
 } VMWARERec, *VMWAREPtr;
 
 #define VMWAREPTR(p) ((VMWAREPtr)((p)->driverPrivate))
@@ -204,6 +225,13 @@ void vmwareSendSVGACmdUpdate(
    VMWAREPtr pVMWARE, BoxPtr pBB
    );
 
+DisplayModeRec *VMWAREAddDisplayMode(
+    ScrnInfoPtr pScrn,
+    const char *name,
+    int width,
+    int height
+   );
+
 /* vmwarecurs.c */
 Bool vmwareCursorInit(
    ScreenPtr pScr
@@ -242,4 +270,10 @@ void vmwareXAACloseScreen(
    ScreenPtr pScreen
    );
 
+/* vmwarectrl.c */
+void VMwareCtrl_ExtInit(ScrnInfoPtr pScrn);
+
+/* vmwarexinerama.c */
+void VMwareXinerama_ExtInit(ScrnInfoPtr pScrn);
+
 #endif
